<?php

namespace App\Console\Commands;

use App\Helpers\Constants;
use App\Models\Crontjob;
use App\Models\Track;
use App\Repositories\TrackRepository;
use Carbon\Carbon;
use Illuminate\Console\Command;

class CrawlerTrackImageCommand extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'crawler:get-track-image';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Lấy ảnh đại diện của bài hát từ nguồn zing';

    protected $trackRepository;

    /**
     * Create a new command instance.
     *
     * CrawlerTrackImageCommand constructor.
     * @param TrackRepository $trackRepository
     */
    public function __construct(TrackRepository $trackRepository)
    {
        parent::__construct();
        ini_set('max_execution_time', -1);
        $this->trackRepository = $trackRepository;
    }

    /**
     * Execute the console command.
     * Cập nhật lưu vào thư mục của năm/tháng hiện tại - 14/05/2020
     *
     * @return mixed
     */
    public function handle()
    {
        $tracks = $this->trackRepository->getTrackImageEmpty(500);

        echo "\nTổng số bài hát cần lấy ảnh về: " . count($tracks);

        if (is_array($tracks) && count($tracks) > 0) {
            /* Kiểm tra đường dẫn tháng hiện tại, chưa có thì tạo mới */
            $current_month = date('Y/m');
            $save_path = Constants::VMUSICCHART_IMG_TRACKS . $current_month;
            if (!file_exists($save_path)) {
                mkdir($save_path, 0755, true);
            }
            /* Duyệt bài còn thiếu ảnh để tải về thư mục tháng hiện tại */
            foreach ($tracks as $key => $track) {
                if ($track['src_thumbnail_medium']) {
                    $file_name = md5($track['id']) . '.png';
                    $file_path = $save_path . '/' . $file_name;

                    @copy(Constants::VMUSICCHART_IMG_EMPTY_PNG, $file_path);
                    @file_put_contents($file_path, @file_get_contents($track['src_thumbnail_medium']));

                    $track = Track::find($track['id']);
                    if ($track) {
                        $track->art = Constants::VMUSICCHART_IMG_TRACKS_DB . $current_month . '/' . $file_name;
                        $track->save();
                    }
                }
            }
        }

        echo "\nTải ảnh kết thúc. \n";

        // Ghi log
        Crontjob::create(['message' => 'CrawlerTrackImageCommand is called at ' . Carbon::now()]);
    }
}
